<?php
/**
 * Seos Portfolio functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Seos_Portfolio
 */

/*********************************** Basic ************************************/
 
if ( ! function_exists( 'seos_portfolio_setup' ) ) :

function seos_portfolio_setup() {

	load_theme_textdomain( 'seos-portfolio', get_template_directory() . '/languages' );

	add_theme_support( 'automatic-feed-links' );

	add_theme_support( 'title-tag' );

	add_theme_support( 'post-thumbnails' );
	
	add_theme_support( 'woocommerce' );
			
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'seos-portfolio' ),
	) );

	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'seos_portfolio_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => esc_url(get_template_directory_uri()) . '/images/background-image.png'
	) ) );
	
	function seos_portfolio_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'seos_portfolio_content_width', 640 );
	}
	
	function seos_portfolio_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar', 'seos-portfolio' ),
			'id'            => 'sidebar-1',
			'description'   => ' ',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
			
	}

	add_action( 'widgets_init', 'seos_portfolio_widgets_init' );

    $font_url = str_replace( ',', '%2C', '//fonts.googleapis.com/css?family=Lato:300,400,700' );
    add_editor_style( $font_url );
	
}
endif;
add_action( 'after_setup_theme', 'seos_portfolio_setup' );

/********************************** Include *************************************/

require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/back-to-top.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/extras.php';
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/css/home-page-image.php';
require get_template_directory() . '/inc/woo-functions.php';

/******************************* Enqueue Scripts ****************************************/

function seos_portfolio_scripts() {
	
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'seos-portfolio-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'seos-portfolio-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css' );	
	wp_enqueue_style( 'font-oswald', '//fonts.googleapis.com/css?family=Oswald:400,300,700', false, 1.0, 'screen' );
	wp_enqueue_style( 'font-Lobster', '//fonts.googleapis.com/css?family=Lobster', false, 1.0, 'screen' );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
    wp_enqueue_style( 'seos_bootstrap-css', get_template_directory_uri() . '/css/bootstrap.min.css' );
	wp_enqueue_style( 'seos_style-css', get_stylesheet_uri() );

}

add_action( 'wp_enqueue_scripts', 'seos_portfolio_scripts' );

/***********************************************************************************
 * Seos Portfolio Buy
***********************************************************************************/

		function seos_portfolio_support($wp_customize){
			class Seos_Portfolio_Customize extends WP_Customize_Control {
				public function render_content() { ?>
				<div class="seos_info"> 
					<em>
						<a href="<?php echo esc_url( 'http://seosthemes.com/seos-portfolio/' ); ?>" title="<?php esc_attr_e( 'Seos Portfolio Buy', 'seos-portfolio' ); ?>" target="_blank">
						<?php _e( 'Preview Premium', 'seos-portfolio' ); ?>
						</a>
					</em>
				</div>
				<?php
				}
			}
		}
		add_action('customize_register', 'seos_portfolio_support');

		function seos_poerfolio_customize_styles( $input ) { ?>
			<style type="text/css">
				#customize-theme-controls #accordion-section-seos_portfolio_buy_section .accordion-section-title,
				#customize-theme-controls #accordion-section-seos_portfolio_buy_section > .accordion-section-title {
					background: #CE0000;
					color: #FFFFFF;
				}
				
				#customize-theme-controls #customize-control-seos_portfolio_setting a {
					font-weight: bold;					
				}
				

			</style>
		<?php }
		
		add_action( 'customize_controls_print_styles', 'seos_poerfolio_customize_styles');

		if ( ! function_exists( 'seos_portfolio_buy' ) ) :
			function seos_portfolio_buy( $wp_customize ) {
				
			$wp_customize->add_panel( 'seos_portfolio_premium', array(
				'title'			=> __('Seos Portfolio Premium', 'seos-portfolio'),
				'priority'		=> 1,
			));				
				
			$wp_customize->add_section( 'seos_portfolio_buy_section', array(
				'title'			=> __('Seos Portfolio Premium Options', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting', array(
						'label'		=> __('Seos Portfolio Premium', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting10', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting10', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Animations Menu</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting10',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting11', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting11', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Animations Social Icons</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting11',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting12', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting12', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Animations Site Title</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting12',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting13', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting13', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Animations Seos Slider</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting13',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting14', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting14', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Animations - Posts and Pages</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting14',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting15', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting15', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Under Construction</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting15',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting16', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting16', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Social Icons</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting16',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting17', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting17', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Portfolio Custom Post Type</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting17',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting18', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting18', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Adsense Fields</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting18',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting19', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting19', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Google Analytics Code</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting19',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting20', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting20', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Sidebar Position</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting20',
						'type'	=> 'text',
					)
				)
			);
			
			$wp_customize->add_setting( 'seos_portfolio_setting21', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'sanitize_text_field',
			));
			$wp_customize->add_control(
				new WP_Customize_Control(
					$wp_customize,'seos_portfolio_setting21', array(
						'description'       => __( '<a target="_blank" href="https://seosthemes.com/seos-portfolio-free-wordpress-theme/">Google Fonts</a>', 'seos-portfolio' ),				
						'section'	=> 'seos_portfolio_buy_section',
						'settings'	=> 'seos_portfolio_setting21',
						'type'	=> 'text',
					)
				)
			);

/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section1', array(
				'title'			=> __('Seos Portfolio Slider', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting1', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting1', array(
						'label'		=> __('Seos Portfolio Slider', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section1',
						'settings'	=> 'seos_portfolio_setting1',
					)
				)
			);
		
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section2', array(
				'title'			=> __('Custom Logo', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting2', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting2', array(
						'label'		=> __('Custom Logo', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section2',
						'settings'	=> 'seos_portfolio_setting2',
					)
				)
			);
				
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section3', array(
				'title'			=> __('Seos Portfolio Theme Boxes', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting3', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting3', array(
						'label'		=> __('Seos Portfolio Theme Boxes', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section3',
						'settings'	=> 'seos_portfolio_setting3',
					)
				)
			);
						
								
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section5', array(
				'title'			=> __('Menu Options', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting5', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting5', array(
						'label'		=> __('Menu Options', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section5',
						'settings'	=> 'seos_portfolio_setting5',
					)
				)
			);
										
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section6', array(
				'title'			=> __('Header Options', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting6', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting6', array(
						'label'		=> __('Header Options', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section6',
						'settings'	=> 'seos_portfolio_setting6',
					)
				)
			);
		
												
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section7', array(
				'title'			=> __('Back to Top', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting7', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting7', array(
						'label'		=> __('Back to Top', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section7',
						'settings'	=> 'seos_portfolio_setting7',
					)
				)
			);
														
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section8', array(
				'title'			=> __('Footer Options', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting8', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting8', array(
						'label'		=> __('Footer Options', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section8',
						'settings'	=> 'seos_portfolio_setting8',
					)
				)
			);
																			
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section9', array(
				'title'			=> __('WooCommerce Options', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting9', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting9', array(
						'label'		=> __('WooCommerce Options', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section9',
						'settings'	=> 'seos_portfolio_setting9',
					)
				)
			);
																
/*************************************************/

			$wp_customize->add_section( 'seos_portfolio_buy_section8', array(
				'title'			=> __('Footer Options', 'seos-portfolio'),
				'panel'			=> 'seos_portfolio_premium',
				'description'	=> __('	Learn more about Seos Portfolio Premium. ','seos-portfolio'),
				'priority'		=> 1,
			));
			
			$wp_customize->add_setting( 'seos_portfolio_setting8', array(
				'capability'		=> 'edit_theme_options',
				'sanitize_callback'	=> 'wp_filter_nohtml_kses',
			));
			$wp_customize->add_control(
				new Seos_Portfolio_Customize(
					$wp_customize,'seos_portfolio_setting8', array(
						'label'		=> __('Footer Options', 'seos-portfolio'),
						'section'	=> 'seos_portfolio_buy_section8',
						'settings'	=> 'seos_portfolio_setting8',
					)
				)
			);
		
		
		}
		endif;
		 
		add_action('customize_register', 'seos_portfolio_buy');
		
		
function customize_styles_agama_support( $input ) { ?>
	<style type="text/css">


#customize-theme-controls #accordion-section-seos_portfolio_buy_section1 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section2 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section3 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section4 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section5 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section6 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section7 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section8 .accordion-section-title:after,
#customize-theme-controls #accordion-section-seos_portfolio_buy_section9 .accordion-section-title:after {
			font-size: 13px;
			font-weight: bold;
			content: "Premium";
			float: right;
			right: 40px;
			position: relative;
			color: #FF0000;
		}
		
		#_customize-input-seos_portfolio_setting10,
		#_customize-input-seos_portfolio_setting11,
		#_customize-input-seos_portfolio_setting12,
		#_customize-input-seos_portfolio_setting13,
		#_customize-input-seos_portfolio_setting14,
		#_customize-input-seos_portfolio_setting15,
		#_customize-input-seos_portfolio_setting16,
		#_customize-input-seos_portfolio_setting17,
		#_customize-input-seos_portfolio_setting18,
		#_customize-input-seos_portfolio_setting19,
		#_customize-input-seos_portfolio_setting20,
		#_customize-input-seos_portfolio_setting21 {
			display: none !important;
		}
		

	</style>
<?php }
add_action( 'customize_controls_print_styles', 'customize_styles_agama_support');			
